Read-only mirrors. Development, issues and pull requests are on GitHub.

summaryrefslogtreecommitdiffhomepage
path: root/tests/TestScripts/testConfigureDisableStringification.py
diff options
context:
space:
mode:
authorMartin Hořeňovský2025-09-22 22:41:14 +0200
committerMartin Hořeňovský2025-09-27 22:43:14 +0200
commita00d6544375e92ccedec786aaee47ac392ea4900 (patch)
treeb989e018ee884edcc12b604b6e9477b36cc6f38c /tests/TestScripts/testConfigureDisableStringification.py
parent756ae05d307168eaa27bd904dbd8e591a6406889 (diff)
downloadcatch3-a00d6544375e92ccedec786aaee47ac392ea4900.tar.gz
Speed up processing mostly visible strings in convertIntoString
This commit causes small (~5%) slowdown when processing strings that consist mostly of escaped characters, but improves throughput by about 100% for strings that consist mostly of characters that do not need escaping.
Diffstat (limited to 'tests/TestScripts/testConfigureDisableStringification.py')
0 files changed, 0 insertions, 0 deletions